==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ro-RO/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirmarea activelor șterse în bloc',
    'bulk_restore'      => 'Confirmare active Restaurare în bloc', 
  'bulk_delete_help'	=> 'Consultați mai jos activele pentru ștergerea în bloc. Odată șterse, aceste active pot fi restaurate, dar nu vor mai fi asociate cu utilizatorii cărora li se alocă în prezent.',
  'bulk_restore_help'	=> 'Revizuiește activele pentru restaurare în masă mai jos. Odată restaurate, aceste active nu vor fi asociate cu niciun utilizator căruia i-a fost atribuit anterior.',
  'bulk_delete_warn'	=> 'Sunteți pe cale să ștergeți: active_count assets.',
  'bulk_restore_warn'	=> 'Ești pe cale să restaurezi :asset_count assets.',
    'bulk_update'		=> 'Actualizarea activelor în bloc',
    'bulk_update_help'	=> 'Acest formular vă permite să actualizați simultan mai multe elemente. Completați câmpurile pe care trebuie să le schimbați. Toate câmpurile rămase necompletate vor rămâne neschimbate.',
    'bulk_update_warn'	=> 'Sunteți pe cale să editați proprietățile unui singur activ. Sunteți pe cale să editați proprietățile din :asset_count assets.',
    'bulk_update_with_custom_field' => 'Notă: activele sunt :asset_model_count diferite tipuri de modele.',
    'bulk_update_model_prefix' => 'Pe modele', 
    'bulk_update_custom_field_unique' => 'Acesta este un câmp unic și nu poate fi editat în vrac.',
    'checkedout_to'		=> 'Alocat la',
    'checkout_date'		=> 'Verifica data',
    'checkin_date'		=> 'Verificați data',
    'checkout_to'		=> 'De alocat la',
    'cost'				=> 'Cost achizitie',
    'create'			=> 'Creeaza activ',
    'date'				=> 'Data achizitie',
    'depreciation'	    => 'Depreciere',
    'depreciates_on'	=> 'Depreciere la',
    'default_location'	=> 'Locatie implicita',
    'default_location_phone' => 'Telefon Locație Implicit',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'Rata EOL',
    'expected_checkin'  => 'Data de așteptare așteptată',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Depreciere completa',
    'help_checkout'		=> 'Dacă doriți să alocați imediat acest activ, selectați "Gata de implementat" din lista de stare de mai sus.',
    'mac_address'		=> 'Adresa mac',
    'manufacturer'		=> 'Producator',
    'model'				=> 'Model',
    'months'			=> 'Luni',
    'name'				=> 'Nume activ',
    'notes'				=> 'Note',
    'order'				=> 'Numar ordine',
    'qr'				=> 'Cod QR',
    'requestable'		=> 'Utilizatorii pot cere acest activ',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Selecteaza tip status',
    'serial'			=> 'Serie',
    'status'			=> 'Stare',
    'tag'				=> 'Eticheta activ',
    'update'			=> 'Actualizeaza activ',
    'warranty'			=> 'Garantie',
        'warranty_expires'		=> 'Garanția expiră',
    'years'				=> 'Ani',
    'asset_location' => 'Actualizați locația activului',
    'asset_location_update_default_current' => 'Actualizați locația implicită ȘI locația curentă',
    'asset_location_update_default' => 'Actualizați doar locația implicită',
    'asset_location_update_actual' => 'Actualizează doar locația reală',
    'asset_not_deployable' => 'Activul este indisponibil și nu poate fi eliberat.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Activul e disponibil și poate fi eliberat.',
    'processing_spinner' => 'Procesare... (Ar putea dura puţin timp pe fişiere mari)',
    'optional_infos'  => 'Informații opționale',
    'order_details'   => 'Informații legate de comandă'
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ro-RO/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirmarea activelor șterse în bloc',
    'bulk_restore'      => 'Confirmare active Restaurare în bloc', 
  'bulk_delete_help'	=> 'Consultați mai jos activele pentru ștergerea în bloc. Odată șterse, aceste active pot fi restaurate, dar nu vor mai fi asociate cu utilizatorii cărora li se alocă în prezent.',
  'bulk_restore_help'	=> 'Revizuiește activele pentru restaurare în masă mai jos. Odată restaurate, aceste active nu vor fi asociate cu niciun utilizator căruia i-a fost atribuit anterior.',
  'bulk_delete_warn'	=> 'Sunteți pe cale să ștergeți: active_count assets.',
  'bulk_restore_warn'	=> 'Ești pe cale să restaurezi :asset_count assets.',
    'bulk_update'		=> 'Actualizarea activelor în bloc',
    'bulk_update_help'	=> 'Acest formular vă permite să actualizați simultan mai multe elemente. Completați câmpurile pe care trebuie să le schimbați. Toate câmpurile rămase necompletate vor rămâne neschimbate.',
    'bulk_update_warn'	=> 'Sunteți pe cale să editați proprietățile unui singur activ. Sunteți pe cale să editați proprietățile din :asset_count assets.',
    'bulk_update_with_custom_field' => 'Notă: activele sunt :asset_model_count diferite tipuri de modele.',
    'bulk_update_model_prefix' => 'Pe modele', 
    'bulk_update_custom_field_unique' => 'Acesta este un câmp unic și nu poate fi editat în vrac.',
    'checkedout_to'		=> 'Alocat la',
    'checkout_date'		=> 'Verifica data',
    'checkin_date'		=> 'Verificați data',
    'checkout_to'		=> 'De alocat la',
    'cost'				=> 'Cost achizitie',
    'create'			=> 'Creeaza activ',
    'date'				=> 'Data achizitie',
    'depreciation'	    => 'Depreciere',
    'depreciates_on'	=> 'Depreciere la',
    'default_location'	=> 'Locatie implicita',
    'default_location_phone' => 'Telefon Locație Implicit',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'Rata EOL',
    'expected_checkin'  => 'Data de așteptare așteptată',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Depreciere completa',
    'help_checkout'		=> 'Dacă doriți să alocați imediat acest activ, selectați "Gata de implementat" din lista de stare de mai sus.',
    'mac_address'		=> 'Adresa mac',
    'manufacturer'		=> 'Producator',
    'model'				=> 'Model',
    'months'			=> 'Luni',
    'name'				=> 'Nume activ',
    'notes'				=> 'Note',
    'order'				=> 'Numar ordine',
    'qr'				=> 'Cod QR',
    'requestable'		=> 'Utilizatorii pot cere acest activ',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Selecteaza tip status',
    'serial'			=> 'Serie',
    'status'			=> 'Stare',
    'tag'				=> 'Eticheta activ',
    'update'			=> 'Actualizeaza activ',
    'warranty'			=> 'Garantie',
        'warranty_expires'		=> 'Garanția expiră',
    'years'				=> 'Ani',
    'asset_location' => 'Actualizați locația activului',
    'asset_location_update_default_current' => 'Actualizați locația implicită ȘI locația curentă',
    'asset_location_update_default' => 'Actualizați doar locația implicită',
    'asset_location_update_actual' => 'Actualizează doar locația reală',
    'asset_not_deployable' => 'Activul este indisponibil și nu poate fi eliberat.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Activul e disponibil și poate fi eliberat.',
    'processing_spinner' => 'Procesare... (Ar putea dura puţin timp pe fişiere mari)',
    'optional_infos'  => 'Informații opționale',
    'order_details'   => 'Informații legate de comandă',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];
